

base_headers = {
  "Host": "kimi.moonshot.cn",
  "Connection": "keep-alive",
  "Pragma": "no-cache",
  "Cache-Control": "no-cache",
  "X-MSH-Session-ID": "None",
  "sec-ch-ua-platform": "Windows",
  "x-msh-platform": "web",
  "X-MSH-Device-ID": "None",
  "R-Timezone": "None",
  "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36 Edg/130.0.0.0",
  "Content-Type": "application/json",
}